# Yahel
Yahel is a Python package for graph visualization. It supports creating interactive and static graphs quickly and easily. 

Yahel é um package Python para visualização de gráficos. Ele oferece suporte para criar gráficos interativos e estáticos de forma fácil e rápida. 

## Funcionalidades
- Gráfico de Barra
- Gráfico de Linha
- Gráfico de Pizza
- Gráfico de Histograma

## Instalação
Instale via pip:
```bash
pip install yahel
